@@ -158,7 +158,6 @@ private:
 
     QPointer<NeoChatRoom> m_room;
     QPointer<ChatBarCache> m_chatBarCache;
-    bool completionVisible = false;
 
     QColor m_mentionColor;
     QColor m_errorColor;
@@ -172,7 +171,5 @@ private:
 
     SyntaxHighlighter *m_highlighter = nullptr;
 
-    CompletionModel::AutoCompletionType m_completionType = CompletionModel::None;
-
     CompletionModel *m_completionModel = nullptr;
 };
