@@ -7,10 +7,7 @@
 #include <qt6keychain/keychain.h>
 
 #include <KLocalizedString>
-#include <KWindowConfig>
 
-#include <QFile>
-#include <QFileInfo>
 #include <QGuiApplication>
 #include <QNetworkProxy>
 #include <QQuickTextDocument>
@@ -28,13 +25,11 @@
 #include <Quotient/eventstats.h>
 #include <Quotient/jobs/downloadfilejob.h>
 #include <Quotient/qt_connection_util.h>
-#include <Quotient/user.h>
 
 #include "neochatconfig.h"
 #include "neochatroom.h"
 #include "notificationsmanager.h"
 #include "roommanager.h"
-#include "windowcontroller.h"
 
 #if defined(Q_OS_WIN) || defined(Q_OS_MAC)
 #include "trayicon.h"
@@ -68,7 +63,6 @@ Controller::Controller(QObject *parent)
         connect(c, &Connection::connected, this, [c, this]() {
             m_accountRegistry.add(c);
             c->syncLoop();
-            Q_EMIT initiated();
         });
     }
 
@@ -78,8 +72,7 @@ Controller::Controller(QObject *parent)
     });
 
 #ifndef Q_OS_WINDOWS
-    // Setup Unix signal handlers
-    const auto unixExitHandler = [](int /*sig*/) -> void {
+    const auto unixExitHandler = [](int) -> void {
         QCoreApplication::quit();
     };
 
@@ -105,7 +98,7 @@ Controller::Controller(QObject *parent)
     connect(&m_accountRegistry, &AccountRegistry::accountCountChanged, this, [this]() {
         if (m_accountRegistry.size() > oldAccountCount) {
             auto connection = dynamic_cast<NeoChatConnection *>(m_accountRegistry.accounts()[m_accountRegistry.size() - 1]);
-            connect(connection, &NeoChatConnection::syncDone, this, [this, connection]() {
+            connect(connection, &NeoChatConnection::syncDone, this, [connection]() {
                 NotificationsManager::instance().handleNotifications(connection);
             });
             connectSingleShot(connection, &NeoChatConnection::syncDone, this, [this, connection] {
@@ -137,23 +130,6 @@ Controller &Controller::instance()
     return _instance;
 }
 
-void Controller::toggleWindow()
-{
-    auto &instance = WindowController::instance();
-    auto window = instance.window();
-    if (window->isVisible()) {
-        if (window->windowStates() & Qt::WindowMinimized) {
-            window->showNormal();
-            window->requestActivate();
-        } else {
-            window->close();
-        }
-    } else {
-        instance.showAndRaiseWindow({});
-        instance.window()->requestActivate();
-    }
-}
-
 void Controller::addConnection(NeoChatConnection *c)
 {
     Q_ASSERT_X(c, __FUNCTION__, "Attempt to add a null connection");
@@ -162,9 +138,7 @@ void Controller::addConnection(NeoChatConnection *c)
 
     c->setLazyLoading(true);
 
-    connect(c, &NeoChatConnection::syncDone, this, [this, c] {
-        Q_EMIT syncDone();
-
+    connect(c, &NeoChatConnection::syncDone, this, [c] {
         c->sync(30000);
         c->saveState();
     });
@@ -172,12 +146,6 @@ void Controller::addConnection(NeoChatConnection *c)
         dropConnection(c);
     });
 
-    connect(c, &NeoChatConnection::requestFailed, this, [this](BaseJob *job) {
-        if (job->error() == BaseJob::UserConsentRequired) {
-            Q_EMIT userConsentRequired(job->errorUrl());
-        }
-    });
-
     c->sync();
 
     Q_EMIT connectionAdded(c);
@@ -194,18 +162,13 @@ void Controller::dropConnection(NeoChatConnection *c)
 void Controller::invokeLogin()
 {
     const auto accounts = SettingsGroup("Accounts"_ls).childGroups();
-    QString id = NeoChatConfig::self()->activeConnection();
     for (const auto &accountId : accounts) {
         AccountSettings account{accountId};
         m_accountsLoading += accountId;
         Q_EMIT accountsLoadingChanged();
-        if (id.isEmpty()) {
-            // handle case where the account config is empty
-            id = accountId;
-        }
         if (!account.homeserver().isEmpty()) {
             auto accessTokenLoadingJob = loadAccessTokenFromKeyChain(account);
-            connect(accessTokenLoadingJob, &QKeychain::Job::finished, this, [accountId, id, this, accessTokenLoadingJob](QKeychain::Job *) {
+            connect(accessTokenLoadingJob, &QKeychain::Job::finished, this, [accountId, this, accessTokenLoadingJob](QKeychain::Job *) {
                 AccountSettings account{accountId};
                 QString accessToken;
                 if (accessTokenLoadingJob->error() == QKeychain::Error::NoError) {
@@ -215,30 +178,11 @@ void Controller::invokeLogin()
                 }
 
                 auto connection = new NeoChatConnection(account.homeserver());
-                connect(connection, &NeoChatConnection::connected, this, [this, connection, id] {
+                connect(connection, &NeoChatConnection::connected, this, [this, connection] {
                     connection->loadState();
                     addConnection(connection);
                     m_accountsLoading.removeAll(connection->userId());
                     Q_EMIT accountsLoadingChanged();
-                    if (connection->userId() == id) {
-                        setActiveConnection(connection);
-                        connectSingleShot(connection, &NeoChatConnection::syncDone, this, &Controller::initiated);
-                    }
-                });
-                connect(connection, &NeoChatConnection::loginError, this, [this, connection](const QString &error, const QString &) {
-                    if (error == "Unrecognised access token"_ls) {
-                        Q_EMIT errorOccured(i18n("Login Failed: Access Token invalid or revoked"), {});
-                        connection->logout(false);
-                    } else if (error == "Connection closed"_ls) {
-                        Q_EMIT errorOccured(i18n("Login Failed: %1", error), {});
-                        // Failed due to network connection issue. This might happen when the homeserver is
-                        // temporary down, or the user trying to re-launch NeoChat in a network that cannot
-                        // connect to the homeserver. In this case, we don't want to do logout().
-                    } else {
-                        Q_EMIT errorOccured(i18n("Login Failed: %1", error), {});
-                        connection->logout(true);
-                    }
-                    Q_EMIT initiated();
                 });
                 connect(connection, &NeoChatConnection::networkError, this, [this](const QString &error, const QString &, int, int) {
                     Q_EMIT errorOccured(i18n("Network Error: %1", error), {});
@@ -247,9 +191,6 @@ void Controller::invokeLogin()
             });
         }
     }
-    if (accounts.isEmpty()) {
-        Q_EMIT initiated();
-    }
 }
 
 QKeychain::ReadPasswordJob *Controller::loadAccessTokenFromKeyChain(const AccountSettings &account)
@@ -322,10 +263,8 @@ void Controller::setQuitOnLastWindowClosed()
     if (NeoChatConfig::self()->systemTray()) {
         m_trayIcon = new TrayIcon(this);
         m_trayIcon->show();
-        connect(m_trayIcon, &TrayIcon::toggleWindow, this, &Controller::toggleWindow);
     } else {
         if (m_trayIcon) {
-            disconnect(m_trayIcon, &TrayIcon::toggleWindow, this, &Controller::toggleWindow);
             delete m_trayIcon;
             m_trayIcon = nullptr;
         }
@@ -352,24 +291,16 @@ void Controller::setActiveConnection(NeoChatConnection *connection)
     }
     m_connection = connection;
     if (connection != nullptr) {
-        NeoChatConfig::self()->setActiveConnection(connection->userId());
         connect(connection, &NeoChatConnection::requestFailed, this, [](BaseJob *job) {
             if (dynamic_cast<DownloadFileJob *>(job) && job->jsonData()["errcode"_ls].toString() == "M_TOO_LARGE"_ls) {
                 RoomManager::instance().warning(i18n("File too large to download."), i18n("Contact your matrix server administrator for support."));
             }
         });
-    } else {
-        NeoChatConfig::self()->setActiveConnection(QString());
     }
     NeoChatConfig::self()->save();
     Q_EMIT activeConnectionChanged();
 }
 
-void Controller::saveWindowGeometry()
-{
-    WindowController::instance().saveGeometry();
-}
-
 void Controller::forceRefreshTextDocument(QQuickTextDocument *textDocument, QQuickItem *item)
 {
     // HACK: Workaround bug QTBUG 93281
@@ -381,10 +312,18 @@ void Controller::listenForNotifications()
 #ifdef HAVE_KUNIFIEDPUSH
     auto connector = new KUnifiedPush::Connector(QStringLiteral("org.kde.neochat"));
 
-    connect(connector, &KUnifiedPush::Connector::messageReceived, [](const QByteArray &data) {
+    auto timer = new QTimer();
+    connect(timer, &QTimer::timeout, qGuiApp, &QGuiApplication::quit);
+
+    connect(connector, &KUnifiedPush::Connector::messageReceived, [timer](const QByteArray &data) {
         NotificationsManager::instance().postPushNotification(data);
+        timer->stop();
     });
 
+    // Wait five seconds to see if we received any messages or this happened to be an erroneous activation.
+    // Otherwise, messageReceived is never activated, and this daemon could stick around forever.
+    timer->start(5000);
+
     connector->registerClient(i18n("Receiving push notifications"));
 #endif
 }
