@@ -355,7 +355,7 @@ QString EventHandler::getBody(const Quotient::RoomEvent *event, Qt::TextFormat f
                 if (e.repeatsState()) {
                     auto text = i18n("reinvited %1 to the room", subjectName);
                     if (!e.reason().isEmpty()) {
-                        text += i18nc("Optional reason for an invitation", ": %1") + e.reason().toHtmlEscaped();
+                        text += i18nc("Optional reason for an invitation", ": %1") + (prettyPrint ? e.reason().toHtmlEscaped() : e.reason());
                     }
                     return text;
                 }
@@ -379,7 +379,9 @@ QString EventHandler::getBody(const Quotient::RoomEvent *event, Qt::TextFormat f
                     if (!e.newDisplayName()) {
                         text = i18nc("their refers to a singular user", "cleared their display name");
                     } else {
-                        text = i18nc("their refers to a singular user", "changed their display name to %1", e.newDisplayName()->toHtmlEscaped());
+                        text = i18nc("their refers to a singular user",
+                                     "changed their display name to %1",
+                                     prettyPrint ? e.newDisplayName()->toHtmlEscaped() : *e.newDisplayName());
                     }
                 }
                 if (e.isAvatarUpdate()) {
@@ -415,7 +417,7 @@ QString EventHandler::getBody(const Quotient::RoomEvent *event, Qt::TextFormat f
                     if (e.reason().isEmpty()) {
                         return i18n("banned %1 from the room", subjectName);
                     } else {
-                        return i18n("banned %1 from the room: %2", subjectName, e.reason().toHtmlEscaped());
+                        return i18n("banned %1 from the room: %2", subjectName, prettyPrint ? e.reason().toHtmlEscaped() : e.reason());
                     }
                 } else {
                     return i18n("self-banned from the room");
@@ -431,8 +433,8 @@ QString EventHandler::getBody(const Quotient::RoomEvent *event, Qt::TextFormat f
         [](const RoomCanonicalAliasEvent &e) {
             return (e.alias().isEmpty()) ? i18n("cleared the room main alias") : i18n("set the room main alias to: %1", e.alias());
         },
-        [](const RoomNameEvent &e) {
-            return (e.name().isEmpty()) ? i18n("cleared the room name") : i18n("set the room name to: %1", e.name().toHtmlEscaped());
+        [prettyPrint](const RoomNameEvent &e) {
+            return (e.name().isEmpty()) ? i18n("cleared the room name") : i18n("set the room name to: %1", prettyPrint ? e.name().toHtmlEscaped() : e.name());
         },
         [prettyPrint, stripNewlines](const RoomTopicEvent &e) {
             return (e.topic().isEmpty()) ? i18n("cleared the topic")
@@ -447,14 +449,15 @@ QString EventHandler::getBody(const Quotient::RoomEvent *event, Qt::TextFormat f
         [](const EncryptionEvent &) {
             return i18n("activated End-to-End Encryption");
         },
-        [](const RoomCreateEvent &e) {
-            return e.isUpgrade() ? i18n("upgraded the room to version %1", e.version().isEmpty() ? "1"_ls : e.version().toHtmlEscaped())
-                                 : i18n("created the room, version %1", e.version().isEmpty() ? "1"_ls : e.version().toHtmlEscaped());
+        [prettyPrint](const RoomCreateEvent &e) {
+            return e.isUpgrade()
+                ? i18n("upgraded the room to version %1", e.version().isEmpty() ? "1"_ls : (prettyPrint ? e.version().toHtmlEscaped() : e.version()))
+                : i18n("created the room, version %1", e.version().isEmpty() ? "1"_ls : (prettyPrint ? e.version().toHtmlEscaped() : e.version()));
         },
         [](const RoomPowerLevelsEvent &) {
             return i18nc("'power level' means permission level", "changed the power levels for this room");
         },
-        [](const StateEvent &e) {
+        [prettyPrint](const StateEvent &e) {
             if (e.matrixType() == QLatin1String("m.room.server_acl")) {
                 return i18n("changed the server access control lists for this room");
             }
@@ -471,7 +474,7 @@ QString EventHandler::getBody(const Quotient::RoomEvent *event, Qt::TextFormat f
                 return e.contentJson()["description"_ls].toString();
             }
             return e.stateKey().isEmpty() ? i18n("updated %1 state", e.matrixType())
-                                          : i18n("updated %1 state for %2", e.matrixType(), e.stateKey().toHtmlEscaped());
+                                          : i18n("updated %1 state for %2", e.matrixType(), prettyPrint ? e.stateKey().toHtmlEscaped() : e.stateKey());
         },
         [](const PollStartEvent &e) {
             return e.question();
@@ -774,97 +777,6 @@ QVariantMap EventHandler::getMediaInfoFromFileInfo(const EventContent::FileInfo
     return mediaInfo;
 }
 
-QSharedPointer<LinkPreviewer> EventHandler::getLinkPreviewer() const
-{
-    if (m_room == nullptr) {
-        qCWarning(EventHandling) << "getLinkPreviewer called with m_room set to nullptr.";
-        return nullptr;
-    }
-    if (m_event == nullptr) {
-        qCWarning(EventHandling) << "getLinkPreviewer called with m_event set to nullptr.";
-        return nullptr;
-    }
-    if (!m_event->is<RoomMessageEvent>()) {
-        return nullptr;
-    }
-
-    QString text;
-    auto event = eventCast<const RoomMessageEvent>(m_event);
-    if (event->hasTextContent()) {
-        auto textContent = static_cast<const EventContent::TextContent *>(event->content());
-        if (textContent) {
-            text = textContent->body;
-        } else {
-            text = event->plainBody();
-        }
-    } else {
-        text = event->plainBody();
-    }
-    TextHandler textHandler;
-    textHandler.setData(text);
-
-    QList<QUrl> links = textHandler.getLinkPreviews();
-    if (links.size() > 0) {
-        return QSharedPointer<LinkPreviewer>(new LinkPreviewer(nullptr, m_room, links.size() > 0 ? links[0] : QUrl()));
-    } else {
-        return nullptr;
-    }
-}
-
-QSharedPointer<ReactionModel> EventHandler::getReactions() const
-{
-    if (m_room == nullptr) {
-        qCWarning(EventHandling) << "getReactions called with m_room set to nullptr.";
-        return nullptr;
-    }
-    if (m_event == nullptr) {
-        qCWarning(EventHandling) << "getReactions called with m_event set to nullptr.";
-        return nullptr;
-    }
-    if (!m_event->is<RoomMessageEvent>()) {
-        qCWarning(EventHandling) << "getReactions called with on a non-message event.";
-        return nullptr;
-    }
-
-    auto eventId = m_event->id();
-    const auto &annotations = m_room->relatedEvents(eventId, EventRelation::AnnotationType);
-    if (annotations.isEmpty()) {
-        return nullptr;
-    };
-
-    QMap<QString, QList<User *>> reactions = {};
-    for (const auto &a : annotations) {
-        if (a->isRedacted()) { // Just in case?
-            continue;
-        }
-        if (const auto &e = eventCast<const ReactionEvent>(a)) {
-            reactions[e->key()].append(m_room->user(e->senderId()));
-        }
-    }
-
-    if (reactions.isEmpty()) {
-        return nullptr;
-    }
-
-    QList<ReactionModel::Reaction> res;
-    auto i = reactions.constBegin();
-    while (i != reactions.constEnd()) {
-        QVariantList authors;
-        for (const auto &author : i.value()) {
-            authors.append(m_room->getUser(author));
-        }
-
-        res.append(ReactionModel::Reaction{i.key(), authors});
-        ++i;
-    }
-
-    if (res.size() > 0) {
-        return QSharedPointer<ReactionModel>(new ReactionModel(nullptr, res, m_room->localUser()));
-    } else {
-        return nullptr;
-    }
-}
-
 bool EventHandler::hasReply() const
 {
     if (m_event == nullptr) {
