@@ -64,7 +64,7 @@ struct RemoteImage {
     // iiibiiay (matching notification spec image-data attribute)
     int width;
     int height;
-    int rowStride;
+    qsizetype rowStride;
     bool hasAlpha;
     int bitsPerSample;
     int channels;
@@ -165,8 +165,17 @@ class Runner : public QObject, protected QDBusContext
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.krunner1")
+    QML_ELEMENT
+    QML_SINGLETON
+
+    Q_PROPERTY(RoomListModel *roomListModel READ roomListModel WRITE setRoomListModel NOTIFY roomListModelChanged)
 public:
-    Runner();
+    static Runner *create(QQmlEngine *engine, QJSEngine *)
+    {
+        static Runner instance;
+        engine->setObjectOwnership(&instance, QQmlEngine::CppOwnership);
+        return &instance;
+    }
 
     /**
      * @brief Return a list of KRunner actions.
@@ -185,10 +194,16 @@ public:
      */
     Q_SCRIPTABLE void Run(const QString &id, const QString &actionId);
 
+    void setRoomListModel(RoomListModel *roomListModel);
+    RoomListModel *roomListModel() const;
+
+Q_SIGNALS:
+    void roomListModelChanged();
+
 private:
     RemoteImage serializeImage(const QImage &image);
-    void activeConnectionChanged();
 
     SortFilterRoomListModel m_model;
     RoomListModel m_sourceModel;
+    Runner();
 };
